# Pixar's rib exporter has a bug that mistakenly inserts,
#  ##rifcontrol insert begin -rif abind -rifend
# and,
#  Transform [....]
# when it should use,
#  ConcatTransform [....]
# This converter script corrects these mistakes.
# Malcolm Kesson
# March 5 2019

import sys
import os

class Instance(object):
	def __init__(self):
		self.id = ''
		self.statements = []
	def set_id(self, id_str):
		self.id = id_str
	def get_id(self):
		return self.id
	def add_statement(self, text):
		self.statements.append(text)
	def get_statements(self):
		return self.statements
class InstanceDB(object):
	def __init__(self):
		self.dict = {}
	def add_instance(self, inst, idstr):
		self.dict[idstr] = inst
	def get_instance(self, idstr):
		return self.dict[idstr]
		
def do_strip(ribpath):
	
	if os.path.exists(ribpath) == False:
		print('Error: Cannot find the archive "%s"' % ribpath)
		return
	if os.path.isfile(ribpath) == False:
		print('Error: "%s" is not a regular text file' % ribpath)
		return
	#print('Converting archive rib file\n\t"%s"\n' % ribpath)
	archive_name = os.path.basename(ribpath)[:-4]

	temp_name = archive_name + '_temp.rib'
	base = os.path.dirname(ribpath)
	temp_path = os.path.join(base, temp_name)
	
	in_rib = open(ribpath,'r')
	line = in_rib.readline()
	if line:
		temp_rib = open(temp_path, 'w')
	else:
		in_rib.close()
		print('Error: "%s" is an empty file!' % ribpath)
		return
	write_line = True
	while line:
		line = line.strip() + '\n'
		if line.startswith('##rifcontrol insert begin -rif abind -rifend'):
			write_line = False
			
		# Convert Transform to ConcatTransform
		if line.startswith('Transform '):
			line = 'Concat' + line
		if write_line: 
			temp_rib.write(line)
		line = in_rib.readline()
		write_line = True
		
	in_rib.close()
	temp_rib.close()
	os.remove(ribpath)
	os.rename(temp_path, ribpath)
	
	print('\nThe archive rib file "%s" has been successfully processed.' % ribpath)

if __name__ == '__main__':
	if len(sys.argv) < 2:
		print 'Error. Script must be called with the path to a rib archive.'
		print 'For example:'
		print 'python strip_archive.py FULLPATH_TO_ARCHIVE.rib'
	else:
		do_strip(sys.argv[1])
		#print 'in main'
		#print sys.argv[1]












